/***************************************************************************
 *   Copyright (C) 2007 by Vincenzo Forchi`,,,   *
 *   tus@ken   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "beamdump.h"
#include <qtango.h>
#include <device_factory.h>
#include <QMessageBox>
#include <QPixmap>
#include <QtNetwork/QHostInfo>
BeamDump::BeamDump(QWidget *parent) : QWidget(parent)
{
	ui.setupUi(this);
	proxy=0;
    cmd_logger=0;
	ui.pushBeamDump->setIcon(QIcon("/runtime/elettra/share/icons/clanbomber.png"));
	ui.pushBeamDump->setIconSize(QSize(128,128));
	QString dev_name;
    
    QString logger_name="sr/accessi/plc_pss"; //esxploit control access cmd logging facility - ask G. Scalamera for details
    localhostname = QHostInfo::localHostName();
	if (QApplication::arguments().value(1).toLower() == "booster"){
		ui.pushBeamDump->setText("Booster\nBeam Dump");
		dev_name="booster/interlock/plc_int";
        logmsg = "Richiesta beam dump booster da ";
	}
	else{
		ui.pushBeamDump->setText("Storage Ring\nBeam Dump");
		dev_name="sr/interlock/bpmfastintlk_s";
        logmsg = "Richiesta beam dump anello da ";
	}
	try{
		DeviceFactory* df=DeviceFactory::instance();
		proxy=df->create(dev_name);
		
	}
	catch (DevFailed &e) {
		time_t now = time(NULL);
		QPair<time_t, DevErrorList> err(now, e.errors);
        TLog log(e);
        TUtil::instance()->addLog(log.toTimeErrlistPair(), log.formatMessage());
		exit(1);
	}
	
	try{
        DeviceFactory* df=DeviceFactory::instance();
        cmd_logger=df->create(logger_name);
    }
    catch (DevFailed &e) {
        cmd_logger = 0;
        time_t now = time(NULL);
        QPair<time_t, DevErrorList> err(now, e.errors);
        TLog log(e);
        TUtil::instance()->addLog(log);
        TUtil::instance()->addLog(log.toTimeErrlistPair(), log.formatMessage());
        //QMessageBox::warning(0, "Warning - will not log beam dump requests", TUtil::instance()->formatMessage(err));
        // do not exit !.. 
    }
	connect(ui.pushBeamDump, SIGNAL(clicked()), this, SLOT(beamKill()));
}

BeamDump::~BeamDump()
{
}

void BeamDump::beamKill()
{
	if (QMessageBox::question(this, "Beam Dump", "Do you really want to dump the beam?", QMessageBox::Yes, QMessageBox::No) == QMessageBox::Yes){
		try {
			
			proxy->command_inout("beam_dump");
			
		} catch (DevFailed &e) {
			time_t now = time(NULL);
			QPair<time_t, DevErrorList> err(now, e.errors);
            TLog log(e);
            TUtil::instance()->addLog(log.toTimeErrlistPair(), log.formatMessage());
		}
		if(cmd_logger){
            try {
                string logentry=logmsg+localhostname.toStdString();
                DeviceData datain; //use direct constructor for DeviceData
                datain << logentry;
                cmd_logger->command_inout("Log_cmd",datain);
                
            } catch (DevFailed &e) {
                time_t now = time(NULL);
                QPair<time_t, DevErrorList> err(now, e.errors);
                TLog log(e);
                TUtil::instance()->addLog(log.toTimeErrlistPair(), log.formatMessage());
            }
        }
	}
}

